You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flink.apache.org by ch...@apache.org on 2019/01/09 13:37:53 UTC

[flink] branch master updated: [hotfix][docs] Add missing config option descriptions

This is an automated email from the ASF dual-hosted git repository.

chesnay pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/flink.git


The following commit(s) were added to refs/heads/master by this push:
     new 43a7497  [hotfix][docs] Add missing config option descriptions
43a7497 is described below

commit 43a74977de27869e41e97878e821dcf363d81911
Author: Yangze Guo <ka...@gmail.com>
AuthorDate: Wed Jan 9 21:37:44 2019 +0800

    [hotfix][docs] Add missing config option descriptions
---
 docs/_includes/generated/common_section.html       |  2 +-
 docs/_includes/generated/core_configuration.html   |  4 +-
 .../generated/history_server_configuration.html    |  2 +-
 .../generated/job_manager_configuration.html       |  2 +-
 docs/_includes/generated/metric_configuration.html |  8 +--
 .../generated/resource_manager_configuration.html  |  2 +-
 .../generated/task_manager_configuration.html      |  2 +-
 docs/_includes/generated/web_configuration.html    | 30 ++++++------
 .../apache/flink/configuration/CoreOptions.java    |  6 ++-
 .../flink/configuration/HistoryServerOptions.java  |  3 +-
 .../flink/configuration/JobManagerOptions.java     |  3 +-
 .../apache/flink/configuration/MetricOptions.java  | 16 ++++--
 .../configuration/ResourceManagerOptions.java      | 11 ++++-
 .../flink/configuration/TaskManagerOptions.java    |  8 +--
 .../org/apache/flink/configuration/WebOptions.java | 57 ++++++++++++++--------
 15 files changed, 98 insertions(+), 58 deletions(-)

diff --git a/docs/_includes/generated/common_section.html b/docs/_includes/generated/common_section.html
index 65804db..1c6685b 100644
--- a/docs/_includes/generated/common_section.html
+++ b/docs/_includes/generated/common_section.html
@@ -20,7 +20,7 @@
         <tr>
             <td><h5>parallelism.default</h5></td>
             <td style="word-wrap: break-word;">1</td>
-            <td></td>
+            <td>Default parallelism for jobs.</td>
         </tr>
         <tr>
             <td><h5>taskmanager.numberOfTaskSlots</h5></td>
diff --git a/docs/_includes/generated/core_configuration.html b/docs/_includes/generated/core_configuration.html
index 4366e8b..5402900 100644
--- a/docs/_includes/generated/core_configuration.html
+++ b/docs/_includes/generated/core_configuration.html
@@ -25,12 +25,12 @@
         <tr>
             <td><h5>io.tmp.dirs</h5></td>
             <td style="word-wrap: break-word;">'LOCAL_DIRS' on Yarn. '_FLINK_TMP_DIR' on Mesos. System.getProperty("java.io.tmpdir") in standalone.</td>
-            <td></td>
+            <td>Directories for temporary files, separated by",", "|", or the system's java.io.File.pathSeparator.</td>
         </tr>
         <tr>
             <td><h5>parallelism.default</h5></td>
             <td style="word-wrap: break-word;">1</td>
-            <td></td>
+            <td>Default parallelism for jobs.</td>
         </tr>
     </tbody>
 </table>
diff --git a/docs/_includes/generated/history_server_configuration.html b/docs/_includes/generated/history_server_configuration.html
index 272606e..7691c0a 100644
--- a/docs/_includes/generated/history_server_configuration.html
+++ b/docs/_includes/generated/history_server_configuration.html
@@ -30,7 +30,7 @@
         <tr>
             <td><h5>historyserver.web.refresh-interval</h5></td>
             <td style="word-wrap: break-word;">10000</td>
-            <td></td>
+            <td>The refresh interval for the HistoryServer web-frontend in milliseconds.</td>
         </tr>
         <tr>
             <td><h5>historyserver.web.ssl.enabled</h5></td>
diff --git a/docs/_includes/generated/job_manager_configuration.html b/docs/_includes/generated/job_manager_configuration.html
index 99eec1d..177c362 100644
--- a/docs/_includes/generated/job_manager_configuration.html
+++ b/docs/_includes/generated/job_manager_configuration.html
@@ -10,7 +10,7 @@
         <tr>
             <td><h5>jobmanager.archive.fs.dir</h5></td>
             <td style="word-wrap: break-word;">(none)</td>
-            <td></td>
+            <td>Dictionary for JobManager to store the archives of completed jobs.</td>
         </tr>
         <tr>
             <td><h5>jobmanager.execution.attempts-history-size</h5></td>
diff --git a/docs/_includes/generated/metric_configuration.html b/docs/_includes/generated/metric_configuration.html
index 420bb7f..39a76ce 100644
--- a/docs/_includes/generated/metric_configuration.html
+++ b/docs/_includes/generated/metric_configuration.html
@@ -50,12 +50,12 @@
         <tr>
             <td><h5>metrics.reporters</h5></td>
             <td style="word-wrap: break-word;">(none)</td>
-            <td></td>
+            <td>An optional list of reporter names. If configured, only reporters whose name matches any of the names in the list will be started. Otherwise, all reporters that could be found in the configuration will be started.</td>
         </tr>
         <tr>
             <td><h5>metrics.scope.delimiter</h5></td>
             <td style="word-wrap: break-word;">"."</td>
-            <td></td>
+            <td>Delimiter used to assemble the metric identifier.</td>
         </tr>
         <tr>
             <td><h5>metrics.scope.jm</h5></td>
@@ -90,12 +90,12 @@
         <tr>
             <td><h5>metrics.system-resource</h5></td>
             <td style="word-wrap: break-word;">false</td>
-            <td></td>
+            <td>Flag indicating whether Flink should report system resource metrics such as machine's CPU, memory or network usage.</td>
         </tr>
         <tr>
             <td><h5>metrics.system-resource-probing-interval</h5></td>
             <td style="word-wrap: break-word;">5000</td>
-            <td></td>
+            <td>Interval between probing of system resource metrics specified in milliseconds. Has an effect only when 'metrics.system-resource' is enabled.</td>
         </tr>
     </tbody>
 </table>
diff --git a/docs/_includes/generated/resource_manager_configuration.html b/docs/_includes/generated/resource_manager_configuration.html
index 9243fcd..3448aba 100644
--- a/docs/_includes/generated/resource_manager_configuration.html
+++ b/docs/_includes/generated/resource_manager_configuration.html
@@ -20,7 +20,7 @@
         <tr>
             <td><h5>local.number-resourcemanager</h5></td>
             <td style="word-wrap: break-word;">1</td>
-            <td></td>
+            <td>The number of resource managers start.</td>
         </tr>
         <tr>
             <td><h5>resourcemanager.job.timeout</h5></td>
diff --git a/docs/_includes/generated/task_manager_configuration.html b/docs/_includes/generated/task_manager_configuration.html
index 63bfb04..2093531 100644
--- a/docs/_includes/generated/task_manager_configuration.html
+++ b/docs/_includes/generated/task_manager_configuration.html
@@ -20,7 +20,7 @@
         <tr>
             <td><h5>task.cancellation.timers.timeout</h5></td>
             <td style="word-wrap: break-word;">7500</td>
-            <td></td>
+            <td>Time we wait for the timers in milliseconds to finish all pending timer threads when the stream task is cancelled.</td>
         </tr>
         <tr>
             <td><h5>task.checkpoint.alignment.max-size</h5></td>
diff --git a/docs/_includes/generated/web_configuration.html b/docs/_includes/generated/web_configuration.html
index dbc353d..6fb35e9 100644
--- a/docs/_includes/generated/web_configuration.html
+++ b/docs/_includes/generated/web_configuration.html
@@ -10,77 +10,77 @@
         <tr>
             <td><h5>web.access-control-allow-origin</h5></td>
             <td style="word-wrap: break-word;">"*"</td>
-            <td></td>
+            <td>Access-Control-Allow-Origin header for all responses from the web-frontend.</td>
         </tr>
         <tr>
             <td><h5>web.address</h5></td>
             <td style="word-wrap: break-word;">(none)</td>
-            <td></td>
+            <td>Address for runtime monitor web-frontend server.</td>
         </tr>
         <tr>
             <td><h5>web.backpressure.cleanup-interval</h5></td>
             <td style="word-wrap: break-word;">600000</td>
-            <td></td>
+            <td>Time, in milliseconds, after which cached stats are cleaned up if not accessed.</td>
         </tr>
         <tr>
             <td><h5>web.backpressure.delay-between-samples</h5></td>
             <td style="word-wrap: break-word;">50</td>
-            <td></td>
+            <td>Delay between stack trace samples to determine back pressure in milliseconds.</td>
         </tr>
         <tr>
             <td><h5>web.backpressure.num-samples</h5></td>
             <td style="word-wrap: break-word;">100</td>
-            <td></td>
+            <td>Number of stack trace samples to take to determine back pressure.</td>
         </tr>
         <tr>
             <td><h5>web.backpressure.refresh-interval</h5></td>
             <td style="word-wrap: break-word;">60000</td>
-            <td></td>
+            <td>Time, in milliseconds, after which available stats are deprecated and need to be refreshed (by resampling).</td>
         </tr>
         <tr>
             <td><h5>web.checkpoints.history</h5></td>
             <td style="word-wrap: break-word;">10</td>
-            <td></td>
+            <td>Number of checkpoints to remember for recent history.</td>
         </tr>
         <tr>
             <td><h5>web.history</h5></td>
             <td style="word-wrap: break-word;">5</td>
-            <td></td>
+            <td>Number of archived jobs for the JobManager.</td>
         </tr>
         <tr>
             <td><h5>web.log.path</h5></td>
             <td style="word-wrap: break-word;">(none)</td>
-            <td></td>
+            <td>Path to the log file (may be in /log for standalone but under log directory when using YARN).</td>
         </tr>
         <tr>
             <td><h5>web.refresh-interval</h5></td>
             <td style="word-wrap: break-word;">3000</td>
-            <td></td>
+            <td>Refresh interval for the web-frontend in milliseconds.</td>
         </tr>
         <tr>
             <td><h5>web.ssl.enabled</h5></td>
             <td style="word-wrap: break-word;">true</td>
-            <td></td>
+            <td>Flag indicating whether to override SSL support for the JobManager Web UI.</td>
         </tr>
         <tr>
             <td><h5>web.submit.enable</h5></td>
             <td style="word-wrap: break-word;">true</td>
-            <td></td>
+            <td>Flag indicating whether jobs can be uploaded and run from the web-frontend.</td>
         </tr>
         <tr>
             <td><h5>web.timeout</h5></td>
             <td style="word-wrap: break-word;">10000</td>
-            <td></td>
+            <td>Timeout for asynchronous operations by the WebRuntimeMonitor in milliseconds.</td>
         </tr>
         <tr>
             <td><h5>web.tmpdir</h5></td>
             <td style="word-wrap: break-word;">System.getProperty("java.io.tmpdir")</td>
-            <td></td>
+            <td>Flink web directory which is used by the webmonitor.</td>
         </tr>
         <tr>
             <td><h5>web.upload.dir</h5></td>
             <td style="word-wrap: break-word;">(none)</td>
-            <td></td>
+            <td>Directory for uploading the job jars. If not specified a dynamic directory will be used under the directory specified by JOB_MANAGER_WEB_TMPDIR_KEY.</td>
         </tr>
     </tbody>
 </table>
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/CoreOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/CoreOptions.java
index 4c928fe..a70c020 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/CoreOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/CoreOptions.java
@@ -216,7 +216,8 @@ public class CoreOptions {
 	public static final ConfigOption<String> TMP_DIRS =
 		key("io.tmp.dirs")
 			.defaultValue(System.getProperty("java.io.tmpdir"))
-			.withDeprecatedKeys("taskmanager.tmp.dirs");
+			.withDeprecatedKeys("taskmanager.tmp.dirs")
+			.withDescription("Directories for temporary files, separated by\",\", \"|\", or the system's java.io.File.pathSeparator.");
 
 	// ------------------------------------------------------------------------
 	//  program
@@ -225,7 +226,8 @@ public class CoreOptions {
 	@Documentation.CommonOption(position = Documentation.CommonOption.POSITION_PARALLELISM_SLOTS)
 	public static final ConfigOption<Integer> DEFAULT_PARALLELISM = ConfigOptions
 		.key("parallelism.default")
-		.defaultValue(1);
+		.defaultValue(1)
+		.withDescription("Default parallelism for jobs.");
 
 	// ------------------------------------------------------------------------
 	//  file systems
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/HistoryServerOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/HistoryServerOptions.java
index 12e7f24..a4df23c 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/HistoryServerOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/HistoryServerOptions.java
@@ -76,7 +76,8 @@ public class HistoryServerOptions {
 	 */
 	public static final ConfigOption<Long> HISTORY_SERVER_WEB_REFRESH_INTERVAL =
 		key("historyserver.web.refresh-interval")
-			.defaultValue(10000L);
+			.defaultValue(10000L)
+			.withDescription("The refresh interval for the HistoryServer web-frontend in milliseconds.");
 
 	/**
 	 * Enables/Disables SSL support for the HistoryServer web-frontend. Only relevant if
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/JobManagerOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/JobManagerOptions.java
index cb2dbe6..a91b931 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/JobManagerOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/JobManagerOptions.java
@@ -136,7 +136,8 @@ public class JobManagerOptions {
 	 */
 	public static final ConfigOption<String> ARCHIVE_DIR =
 		key("jobmanager.archive.fs.dir")
-			.noDefaultValue();
+			.noDefaultValue()
+			.withDescription("Dictionary for JobManager to store the archives of completed jobs.");
 
 	/**
 	 * The job store cache size in bytes which is used to keep completed
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/MetricOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/MetricOptions.java
index 0785b34..2c22d92 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/MetricOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/MetricOptions.java
@@ -47,7 +47,10 @@ public class MetricOptions {
 	 */
 	public static final ConfigOption<String> REPORTERS_LIST =
 		key("metrics.reporters")
-			.noDefaultValue();
+			.noDefaultValue()
+			.withDescription("An optional list of reporter names. If configured, only reporters whose name matches" +
+				" any of the names in the list will be started. Otherwise, all reporters that could be found in" +
+				" the configuration will be started.");
 
 	public static final ConfigOption<String> REPORTER_CLASS =
 		key("metrics.reporter.<name>.class")
@@ -68,7 +71,8 @@ public class MetricOptions {
 	/** The delimiter used to assemble the metric identifier. */
 	public static final ConfigOption<String> SCOPE_DELIMITER =
 		key("metrics.scope.delimiter")
-			.defaultValue(".");
+			.defaultValue(".")
+			.withDescription("Delimiter used to assemble the metric identifier.");
 
 	/** The scope format string that is applied to all metrics scoped to a JobManager. */
 	public static final ConfigOption<String> SCOPE_NAMING_JM =
@@ -135,14 +139,18 @@ public class MetricOptions {
 	 */
 	public static final ConfigOption<Boolean> SYSTEM_RESOURCE_METRICS =
 		key("metrics.system-resource")
-			.defaultValue(false);
+			.defaultValue(false)
+			.withDescription("Flag indicating whether Flink should report system resource metrics such as machine's CPU," +
+				" memory or network usage.");
 	/**
 	 * Interval between probing of system resource metrics specified in milliseconds. Has an effect only when
 	 * {@link #SYSTEM_RESOURCE_METRICS} is enabled.
 	 */
 	public static final ConfigOption<Long> SYSTEM_RESOURCE_METRICS_PROBING_INTERVAL =
 		key("metrics.system-resource-probing-interval")
-			.defaultValue(5000L);
+			.defaultValue(5000L)
+			.withDescription("Interval between probing of system resource metrics specified in milliseconds. Has an effect" +
+				" only when '" + SYSTEM_RESOURCE_METRICS.key() + "' is enabled.");
 
 	/**
 	 * The default network port range for Flink's internal metric query service. The {@code "0"} means that
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/ResourceManagerOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/ResourceManagerOptions.java
index 5a203e3..ca6cc14 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/ResourceManagerOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/ResourceManagerOptions.java
@@ -35,10 +35,19 @@ public class ResourceManagerOptions {
 		.defaultValue("5 minutes")
 		.withDescription("Timeout for jobs which don't have a job manager as leader assigned.");
 
+	/**
+	 * The number of resource managers start.
+	 */
 	public static final ConfigOption<Integer> LOCAL_NUMBER_RESOURCE_MANAGER = ConfigOptions
 		.key("local.number-resourcemanager")
-		.defaultValue(1);
+		.defaultValue(1)
+		.withDescription("The number of resource managers start.");
 
+	/**
+	 * Defines the network port to connect to for communication with the resource manager.
+	 * By default, the port of the JobManager, because the same ActorSystem is used. Its not
+	 * possible to use this configuration key to define port ranges.
+	 */
 	public static final ConfigOption<Integer> IPC_PORT = ConfigOptions
 		.key("resourcemanager.rpc.port")
 		.defaultValue(0)
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/TaskManagerOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/TaskManagerOptions.java
index 6d3ac45..6844ee4 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/TaskManagerOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/TaskManagerOptions.java
@@ -375,13 +375,15 @@ public class TaskManagerOptions {
 				" leads to a fatal TaskManager error. A value of 0 deactivates" +
 				" the watch dog.");
 	/**
 	 * This configures how long we wait for the timers to finish all pending timer threads
 	 * when the stream task is cancelled .
 	 */
 	public static final ConfigOption<Long> TASK_CANCELLATION_TIMEOUT_TIMERS = ConfigOptions
 			.key("task.cancellation.timers.timeout")
 			.defaultValue(7500L)
-			.withDeprecatedKeys("timerservice.exceptional.shutdown.timeout");
+			.withDeprecatedKeys("timerservice.exceptional.shutdown.timeout")
+			.withDescription("Time we wait for the timers in milliseconds to finish all pending timer threads" +
+				" when the stream task is cancelled.");
 
 	/**
 	 * The maximum number of bytes that a checkpoint alignment may buffer.
@@ -375,13 +375,15 @@ public class TaskManagerOptions {
 				" the watch dog.");
 	/**
-	 * This configures how long we wait for the timers to finish all pending timer threads
-	 * when the stream task is cancelled .
+	 * This configures how long we wait for the timers in milliseconds to finish all pending timer threads
+	 * when the stream task is cancelled.
 	 */
 	public static final ConfigOption<Long> TASK_CANCELLATION_TIMEOUT_TIMERS = ConfigOptions
diff --git a/flink-core/src/main/java/org/apache/flink/configuration/WebOptions.java b/flink-core/src/main/java/org/apache/flink/configuration/WebOptions.java
index 6d0a6ec..ba34161 100644
--- a/flink-core/src/main/java/org/apache/flink/configuration/WebOptions.java
+++ b/flink-core/src/main/java/org/apache/flink/configuration/WebOptions.java
@@ -35,7 +35,8 @@ public class WebOptions {
 	public static final ConfigOption<String> ADDRESS =
 		key("web.address")
 			.noDefaultValue()
-			.withDeprecatedKeys("jobmanager.web.address");
+			.withDeprecatedKeys("jobmanager.web.address")
+			.withDescription("Address for runtime monitor web-frontend server.");
 
 	/**
 	 * The port for the runtime monitor web-frontend server.
@@ -55,15 +56,17 @@ public class WebOptions {
 	public static final ConfigOption<String> ACCESS_CONTROL_ALLOW_ORIGIN =
 		key("web.access-control-allow-origin")
 			.defaultValue("*")
-			.withDeprecatedKeys("jobmanager.web.access-control-allow-origin");
+			.withDeprecatedKeys("jobmanager.web.access-control-allow-origin")
+			.withDescription("Access-Control-Allow-Origin header for all responses from the web-frontend.");
 
 	/**
 	 * The config parameter defining the refresh interval for the web-frontend.
 	 */
 	public static final ConfigOption<Long> REFRESH_INTERVAL =
 		key("web.refresh-interval")
 			.defaultValue(3000L)
-			.withDeprecatedKeys("jobmanager.web.refresh-interval");
+			.withDeprecatedKeys("jobmanager.web.refresh-interval")
+			.withDescription("Refresh interval for the web-frontend in milliseconds.");
 
 	/**
 	 * Config parameter to override SSL support for the JobManager Web UI.
@@ -71,7 +74,8 @@ public class WebOptions {
 	public static final ConfigOption<Boolean> SSL_ENABLED =
 		key("web.ssl.enabled")
 			.defaultValue(true)
-			.withDeprecatedKeys("jobmanager.web.ssl.enabled");
+			.withDeprecatedKeys("jobmanager.web.ssl.enabled")
+			.withDescription("Flag indicating whether to override SSL support for the JobManager Web UI.");
 
 	/**
 	 * The config parameter defining the flink web directory to be used by the webmonitor.
@@ -80,7 +84,8 @@ public class WebOptions {
 	public static final ConfigOption<String> TMP_DIR =
 		key("web.tmpdir")
 			.defaultValue(System.getProperty("java.io.tmpdir"))
-			.withDeprecatedKeys("jobmanager.web.tmpdir");
+			.withDeprecatedKeys("jobmanager.web.tmpdir")
+			.withDescription("Flink web directory which is used by the webmonitor.");
 
 	/**
 	 * The config parameter defining the directory for uploading the job jars. If not specified a dynamic directory
@@ -89,15 +94,18 @@ public class WebOptions {
 	public static final ConfigOption<String> UPLOAD_DIR =
 		key("web.upload.dir")
 			.noDefaultValue()
-			.withDeprecatedKeys("jobmanager.web.upload.dir");
+			.withDeprecatedKeys("jobmanager.web.upload.dir")
+			.withDescription("Directory for uploading the job jars. If not specified a dynamic directory will be used" +
+				" under the directory specified by JOB_MANAGER_WEB_TMPDIR_KEY.");
 
 	/**
 	 * The config parameter defining the number of archived jobs for the jobmanager.
 	 */
 	public static final ConfigOption<Integer> ARCHIVE_COUNT =
 		key("web.history")
 			.defaultValue(5)
-			.withDeprecatedKeys("jobmanager.web.history");
+			.withDeprecatedKeys("jobmanager.web.history")
+			.withDescription("Number of archived jobs for the JobManager.");
 
 	/**
 	 * The log file location (may be in /log for standalone but under log directory when using YARN).
@@ -105,7 +113,8 @@ public class WebOptions {
 	public static final ConfigOption<String> LOG_PATH =
 		key("web.log.path")
 			.noDefaultValue()
-			.withDeprecatedKeys("jobmanager.web.log.path");
+			.withDeprecatedKeys("jobmanager.web.log.path")
+			.withDescription("Path to the log file (may be in /log for standalone but under log directory when using YARN).");
 
 	/**
 	 * Config parameter indicating whether jobs can be uploaded and run from the web-frontend.
@@ -113,7 +122,8 @@ public class WebOptions {
 	public static final ConfigOption<Boolean> SUBMIT_ENABLE =
 		key("web.submit.enable")
 			.defaultValue(true)
-			.withDeprecatedKeys("jobmanager.web.submit.enable");
+			.withDeprecatedKeys("jobmanager.web.submit.enable")
+			.withDescription("Flag indicating whether jobs can be uploaded and run from the web-frontend.");
 
 	/**
 	 * Config parameter defining the number of checkpoints to remember for recent history.
@@ -121,23 +131,27 @@ public class WebOptions {
 	public static final ConfigOption<Integer> CHECKPOINTS_HISTORY_SIZE =
 		key("web.checkpoints.history")
 			.defaultValue(10)
-			.withDeprecatedKeys("jobmanager.web.checkpoints.history");
+			.withDeprecatedKeys("jobmanager.web.checkpoints.history")
+			.withDescription("Number of checkpoints to remember for recent history.");
 
 	/**
 	 * Time after which cached stats are cleaned up if not accessed.
 	 */
 	public static final ConfigOption<Integer> BACKPRESSURE_CLEANUP_INTERVAL =
 		key("web.backpressure.cleanup-interval")
 			.defaultValue(10 * 60 * 1000)
-			.withDeprecatedKeys("jobmanager.web.backpressure.cleanup-interval");
+			.withDeprecatedKeys("jobmanager.web.backpressure.cleanup-interval")
+			.withDescription("Time, in milliseconds, after which cached stats are cleaned up if not accessed.");
 
 	/**
 	 * Time after which available stats are deprecated and need to be refreshed (by resampling).
 	 */
 	public static final ConfigOption<Integer> BACKPRESSURE_REFRESH_INTERVAL =
 		key("web.backpressure.refresh-interval")
 			.defaultValue(60 * 1000)
-			.withDeprecatedKeys("jobmanager.web.backpressure.refresh-interval");
+			.withDeprecatedKeys("jobmanager.web.backpressure.refresh-interval")
+			.withDescription("Time, in milliseconds, after which available stats are deprecated and need to be refreshed" +
+				" (by resampling).");
 
 	/**
 	 * Number of stack trace samples to take to determine back pressure.
@@ -145,22 +159,25 @@ public class WebOptions {
 	public static final ConfigOption<Integer> BACKPRESSURE_NUM_SAMPLES =
 		key("web.backpressure.num-samples")
 			.defaultValue(100)
-			.withDeprecatedKeys("jobmanager.web.backpressure.num-samples");
+			.withDeprecatedKeys("jobmanager.web.backpressure.num-samples")
+			.withDescription("Number of stack trace samples to take to determine back pressure.");
 
 	/**
 	 * Delay between stack trace samples to determine back pressure.
 	 */
 	public static final ConfigOption<Integer> BACKPRESSURE_DELAY =
 		key("web.backpressure.delay-between-samples")
 			.defaultValue(50)
-			.withDeprecatedKeys("jobmanager.web.backpressure.delay-between-samples");
+			.withDeprecatedKeys("jobmanager.web.backpressure.delay-between-samples")
+			.withDescription("Delay between stack trace samples to determine back pressure in milliseconds.");
 
 	/**
 	 * Timeout for asynchronous operations by the WebRuntimeMonitor in milliseconds.
 	 */
 	public static final ConfigOption<Long> TIMEOUT =
 		key("web.timeout")
-		.defaultValue(10L * 1000L);
+		.defaultValue(10L * 1000L)
+		.withDescription("Timeout for asynchronous operations by the WebRuntimeMonitor in milliseconds.");
 
 	// ------------------------------------------------------------------------
@@ -55,15 +56,17 @@ public class WebOptions {
 
 	/**
-	 * The config parameter defining the refresh interval for the web-frontend.
+	 * The config parameter defining the refresh interval for the web-frontend in milliseconds.
 	 */
 	public static final ConfigOption<Long> REFRESH_INTERVAL =
@@ -89,15 +94,18 @@ public class WebOptions {
 
 	/**
-	 * The config parameter defining the number of archived jobs for the jobmanager.
+	 * The config parameter defining the number of archived jobs for the JobManager.
 	 */
 	public static final ConfigOption<Integer> ARCHIVE_COUNT =
@@ -121,23 +131,27 @@ public class WebOptions {
 
 	/**
-	 * Time after which cached stats are cleaned up if not accessed.
+	 * Time, in milliseconds, after which cached stats are cleaned up if not accessed.
 	 */
 	public static final ConfigOption<Integer> BACKPRESSURE_CLEANUP_INTERVAL =
@@ -121,23 +131,27 @@ public class WebOptions {
 
 	/**
-	 * Time after which available stats are deprecated and need to be refreshed (by resampling).
+	 * Time, in milliseconds, after which available stats are deprecated and need to be refreshed (by resampling).
 	 */
 	public static final ConfigOption<Integer> BACKPRESSURE_REFRESH_INTERVAL =
@@ -145,22 +159,25 @@ public class WebOptions {
 
 	/**
-	 * Delay between stack trace samples to determine back pressure.
+	 * Delay between stack trace samples to determine back pressure in milliseconds.
 	 */
 	public static final ConfigOption<Integer> BACKPRESSURE_DELAY =